pub struct ChildConfig {
pub id: String,
pub script_path: Option<PathBuf>,
pub script_inline: Option<String>,
pub capabilities: Option<Capability>,
}Expand description
Configuration for spawning a child.
Example
use orcs_component::ChildConfig;
use std::path::PathBuf;
// From file
let config = ChildConfig::from_file("worker-1", "scripts/worker.lua");
// From inline script
let config = ChildConfig::from_inline("worker-2", r#"
return {
run = function(input) return input end,
on_signal = function(sig) return "Handled" end,
}
"#);Fields
id: StringUnique identifier for the child.
script_path: Option<PathBuf>Path to the script file (for Lua children).
script_inline: Option<String>Inline script content (for Lua children).
capabilities: Option<Capability>Requested capabilities for the child.
None— inherit all of the parent’s capabilities (default).Some(caps)— request specific capabilities. The effective set isparent_caps & requested_caps(a child cannot exceed its parent).
Implementations
Sourceimpl ChildConfig
impl ChildConfig
Sourcepub fn from_file(id: impl Into<String>, path: impl Into<PathBuf>) -> Self
pub fn from_file(id: impl Into<String>, path: impl Into<PathBuf>) -> Self
Creates a config for a child from a script file.
Sourcepub fn from_inline(id: impl Into<String>, script: impl Into<String>) -> Self
pub fn from_inline(id: impl Into<String>, script: impl Into<String>) -> Self
Creates a config for a child from inline script.
Sourcepub fn with_capabilities(self, caps: Capability) -> Self
pub fn with_capabilities(self, caps: Capability) -> Self
Sets the requested capabilities for this child.
The effective capabilities will be parent_caps & requested_caps.